@@ -3,9 +3,9 @@ using namespace Rcpp;
 
 // [[Rcpp::export]]
 NumericVector squishn(NumericVector x, double a, double b, bool in_place = false) {
-  int N = x.size();
+  R_xlen_t N = x.size();
   NumericVector out = in_place ? NumericVector(x) : NumericVector(clone(x));
-  for (int i = 0; i < N; ++i) {
+  for (R_xlen_t i = 0; i < N; ++i) {
     if (x[i] < a) {
       out[i] = a;
     } else if (x[i] > b) {
@@ -17,9 +17,9 @@ NumericVector squishn(NumericVector x, double a, double b, bool in_place = false
 
 // [[Rcpp::export]]
 IntegerVector squishi(IntegerVector x, int a, int b, bool in_place = false) {
-  int N = x.size();
+  R_xlen_t N = x.size();
   IntegerVector out = in_place ? IntegerVector(x) : IntegerVector(clone(x));
-  for (int i = 0; i < N; ++i) {
+  for (R_xlen_t i = 0; i < N; ++i) {
     if (x[i] < a) {
       out[i] = a;
     } else if (x[i] > b) {
