@@ -301,3 +301,140 @@ test_that("lhs_eval length 0", {
   expect_equal(.which_first(c(NA, NA)), 0L)
 })
 
+
+test_that("which_first logical", {
+  #10
+  x <- y <- c(TRUE, FALSE, NA)
+  expect_equal(which_first(x != y), 0)
+  expect_equal(which_first(x == y), 1)
+  expect_equal(which_first(x > y), 0)
+  expect_equal(which_first(x < y), 0)
+
+  y <- as.integer(x)
+  expect_equal(which_first(x != y), 0)
+
+  y <- c(2L, 0L, NA)
+  expect_equal(which_first(x != y), 1)
+
+
+})
+
+test_that("which_first_logical %in%", {
+  x <- c(TRUE, FALSE, TRUE, FALSE)
+  y <- c(TRUE, FALSE)
+  expect_equal(which_first(x %in% y), 1)
+
+  x <- rev(x)
+  expect_equal(which_first(x %in% y), 1)
+
+  xx <- logical(10)
+  yy <- logical(4)
+  expect_equal(which_first(xx %in% yy), 1)
+  yy <- !yy
+  expect_equal(which_first(xx %in% yy), 0)
+
+  yy <- c(TRUE, NA)
+  expect_equal(which_first(xx %in% yy), 0)
+  xx[3] <- TRUE
+  expect_equal(which_first(xx %in% yy), 3)
+  xx[3] <- NA
+  expect_equal(which_first(xx %in% yy), 3)
+
+
+
+  yyy <- TRUE
+  expect_equal(which_first(xx %in% yyy), 0)
+  yyy <- FALSE
+  expect_equal(which_first(xx %in% yyy), 1)
+  yyy <- NA
+  expect_equal(which_first(xx %in% yyy), 3)
+
+  xxx <- c(TRUE, FALSE)
+  yyy <- NA
+  expect_equal(which_first(xxx %in% yyy), 0)
+  xxx <- c(TRUE, FALSE)
+  yyy <- TRUE
+  expect_equal(which_first(xxx %in% yyy), 1)
+  yyy <- FALSE
+  expect_equal(which_first(xxx %in% yyy), 2)
+
+  yyy <- c(TRUE, FALSE, NA)
+  expect_equal(which_first(xx %in% yyy), 1)
+
+
+  a <- c(rep(TRUE, 100), NA)
+  b <- c(TRUE, FALSE, TRUE)
+  expect_equal(which_first(a %in% b), 1)
+  a <- c(rep(FALSE, 100), NA)
+  expect_equal(which_first(a %in% b), 1)
+  b <- c(TRUE, TRUE)
+  expect_equal(which_first(a %in% b), 0)
+  b <- c(TRUE, FALSE)
+  expect_equal(which_first(a %in% b), 1)
+  b <- c(TRUE, NA)
+  expect_equal(which_first(a %in% b), 101)
+
+  a <- c(TRUE, TRUE, rep(NA, 100), FALSE, TRUE)
+  b <- c(FALSE, NA)
+  expect_equal(which_first(a %in% b), 3)
+  b <- c(TRUE, NA)
+  expect_equal(which_first(a %in% b), 1)
+
+})
+
+
+
+
+test_that("Error handling", {
+  x <- c(TRUE, FALSE)
+  y <- c(TRUE, FALSE, TRUE)
+  expect_error(which_first(x == y), "length")
+})
+
+test_that("do_which_first_lgl_lgl", {
+  skip_if_not_installed("data.table")
+  library(data.table)
+
+  f <- do_which_first_lgl_lgl
+
+  expect_error(f(c(TRUE, FALSE), c(NA), FALSE, FALSE, FALSE), "lengths")
+                                                         # eq   # lt   # gt
+  expect_equal(f(c(NA, TRUE, FALSE), c(TRUE, FALSE, NA), FALSE, FALSE, FALSE), 1)
+  expect_equal(f(c(NA, TRUE, FALSE), c(TRUE, FALSE, NA), FALSE, FALSE, TRUE ), 2)
+  expect_equal(f(c(NA, TRUE, FALSE), c(TRUE, FALSE, NA), FALSE, TRUE , FALSE), 0)
+  expect_equal(f(c(NA, TRUE, FALSE), c(TRUE, FALSE, NA), TRUE , FALSE, FALSE), 0)
+  expect_equal(f(c(NA, TRUE, FALSE), c(TRUE, FALSE, NA), TRUE , FALSE, TRUE ), 1)
+  expect_equal(f(c(NA, TRUE, FALSE), c(TRUE, FALSE, NA), TRUE , TRUE , FALSE), 1)
+
+  x <- c(logical(5), TRUE, NA, FALSE)
+  y <- c(logical(4), TRUE, TRUE, FALSE, FALSE)
+                      # eq   # lt   # gt
+  expect_equal(f(x, y, FALSE, FALSE, FALSE), 5)
+  expect_equal(f(x, y, TRUE , FALSE, FALSE), 1)
+  expect_equal(f(x, y, TRUE , TRUE , FALSE), 1)
+  expect_equal(f(x, y, FALSE, TRUE , FALSE), 5)
+  expect_equal(f(NA, NA, FALSE, FALSE, FALSE), 0)
+  expect_equal(f(NA, NA, TRUE, FALSE, TRUE , skip_na = FALSE), 1)
+  expect_equal(f(NA, NA, TRUE, TRUE , FALSE, skip_na = FALSE), 1)
+  expect_equal(f(FALSE, NA, TRUE, TRUE, FALSE, skip_na = FALSE), 1)
+  expect_equal(f(FALSE, NA, TRUE, FALSE, TRUE, skip_na = FALSE), 0)
+  expect_equal(f(FALSE, NA, TRUE, FALSE, TRUE, skip_na = TRUE), 0)
+  expect_equal(f(FALSE, FALSE, TRUE, FALSE, TRUE), 1)
+
+})
+
+test_that("do_which_first_lgl_lgl skip_na", {
+  x <- c(NA, NA, TRUE, TRUE, FALSE, FALSE)
+  y <- c(NA, TRUE, NA, FALSE, NA, TRUE)
+  f <- do_which_first_lgl_lgl
+  expect_equal(f(x, y, FALSE, FALSE, FALSE, skip_na = TRUE), 4)
+  expect_equal(f(x, y, TRUE , FALSE, FALSE, skip_na = TRUE), 0)
+  expect_equal(f(x, y, FALSE, FALSE, TRUE , skip_na = TRUE), 4)
+  expect_equal(f(x, y, FALSE, TRUE , FALSE, skip_na = TRUE), 6)
+  expect_equal(f(x, y, TRUE , TRUE , FALSE, skip_na = TRUE), 6)
+  expect_equal(f(x, y, TRUE , TRUE , TRUE, skip_na = TRUE), 4)
+})
+
+
+
+
